@@ -18,16 +18,15 @@ Settings::Settings(QWidget *parent) :
     ui->checkBoxSecureSetting->setChecked(QSettings().value("SecureSettingSilent", true).toBool());
 
 }
-
 Settings::~Settings()
 {
+    QSettings().sync();
     delete ui;
 }
 
 void Settings::on_checkBoxSecureSetting_clicked()
 {
-    QSettings settings;
-    if (ui->checkBoxSecureSetting->isChecked()) settings.setValue("SecureSettingSilent","true");
-    else settings.setValue("SecureSettingSilent","false");
-    settings.sync();
+    if (ui->checkBoxSecureSetting->isChecked()) QSettings().setValue("SecureSettingSilent","true");
+    else QSettings().setValue("SecureSettingSilent","false");
+    QSettings().sync();
 }
